@@ -343,24 +343,9 @@ eog_job_load_run (EogJob *job)
 
 static void eog_job_model_init (EogJobModel *job) { /* Do Nothing */ }
 
-static void
-eog_job_model_dispose (GObject *object)
-{
-	EogJobModel *job;
-
-	job = EOG_JOB_MODEL (object);
-
-	(* G_OBJECT_CLASS (eog_job_model_parent_class)->dispose) (object);
-}
-
 static void
 eog_job_model_class_init (EogJobModelClass *class)
 {
-	GObjectClass *oclass;
-
-	oclass = G_OBJECT_CLASS (class);
-
-	oclass->dispose = eog_job_model_dispose;
 	EOG_JOB_CLASS (class)->run = eog_job_model_run;
 }
 
@@ -424,8 +409,6 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 						      g_file_get_uri (file));
 			break;
 		}
-
-		g_object_unref (file);
 	}
 
 	*file_list  = g_list_reverse (*file_list);
@@ -637,7 +620,7 @@ eog_job_save_run (EogJob *ejob)
 				               G_CALLBACK (save_progress_handler),
 					       job);
 
-		save_info = eog_image_save_info_from_image (image);
+		save_info = eog_image_save_info_new_from_image (image);
 
 		success = eog_image_save_by_info (image,
 						  save_info,
@@ -746,15 +729,15 @@ eog_job_save_as_run (EogJob *ejob)
 				               G_CALLBACK (save_progress_handler),
 					       job);
 
-		src_info = eog_image_save_info_from_image (image);
+		src_info = eog_image_save_info_new_from_image (image);
 
 		if (n_images == 1) {
 			g_assert (saveas_job->file != NULL);
 
 			format = eog_pixbuf_get_format (saveas_job->file);
 
-			dest_info = eog_image_save_info_from_file (saveas_job->file,
-								   format);
+			dest_info = eog_image_save_info_new_from_file (saveas_job->file,
+								       format);
 
 		/* SaveAsDialog has already secured permission to overwrite */
 			if (dest_info->exists) {
@@ -772,8 +755,8 @@ eog_job_save_as_run (EogJob *ejob)
 
 			g_assert (result);
 
-			dest_info = eog_image_save_info_from_file (dest_file,
-								   format);
+			dest_info = eog_image_save_info_new_from_file (dest_file,
+								       format);
 		}
 
 		success = eog_image_save_as_by_info (image,
@@ -788,7 +771,12 @@ eog_job_save_as_run (EogJob *ejob)
 					  NULL,
 					  NULL);
 
-		file_permissions = g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_UNIX_MODE);
+		/* if we can't retrieve file permission apply default */
+		if (info != NULL) {
+			file_permissions = g_file_info_get_attribute_uint32 (info,
+									     G_FILE_ATTRIBUTE_UNIX_MODE);
+			g_object_unref (info);
+		}
 
 		/* apply permission mask to file permissions */
 		file_permissions |= permissions_mask;
@@ -800,8 +788,6 @@ eog_job_save_as_run (EogJob *ejob)
 					     NULL,
 					     NULL);
 
-		g_object_unref (info);
-
 		if (src_info)
 			g_object_unref (src_info);
 
@@ -879,16 +865,12 @@ eog_job_copy_run (EogJob *ejob)
 {
 	EogJobCopy *job;
 	GList *it;
-	guint n_images;
 	GFile *src, *dest;
 	gchar *filename, *dest_filename;
 
 	g_return_if_fail (EOG_IS_JOB_COPY (ejob));
 
 	job = EOG_JOB_COPY (ejob);
-
-	n_images = g_list_length (job->images);
-
 	job->current_pos = 0;
 
 	for (it = job->images; it != NULL; it = g_list_next (it), job->current_pos++) {
